.. dlmhelper documentation master file, created by
   sphinx-quickstart on Thu Aug  3 10:15:00 2023.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to dlmhelper's documentation!
=====================================

.. toctree::
   :maxdepth: 2
   :caption: Contents:
   
   usage
   data
   tools
   spatio_temporal



Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
